@@ -203,6 +203,7 @@ config_field_check() {
       fi
       ;;
     planning)
+      #echo -e "DEBUG: FIELD=${field} VALUE=${value} NULL=${null}"
       if [ -z "${value}" ] && [ "${null}" != "null"  ]
         then
           save_status_backup_error
@@ -211,6 +212,9 @@ config_field_check() {
       elif echo "${value}" | grep -q -w [d,w,m,y]
         then
           return 0
+      elif [ -z "${value}" ] && [ "${null}" = "null"  ]
+        then
+          return 0;
         else
           save_status_backup_error
           report_text field_wrong
@@ -218,7 +222,6 @@ config_field_check() {
       fi
       ;;
     text)
-      #echo -e ${field}: ${value} - ${null}
       if [ -z "${value}" ] && [ "${null}" != "null"  ]
         then
           save_status_backup_error
@@ -946,7 +949,8 @@ show_backup_keep(){
  if [ $1 -eq 0 ]
    then
      #msg "never"
-     echo -n "1 backup"
+     #echo -n "1 backup"
+     echo -n "0 backups"
    else
      echo -n "$1 " ; msg "backups"
  fi
@@ -1109,7 +1113,7 @@ backup_erase_init() {
     check_status_backup 2>&1 > /dev/null ; local status_backup="$?"
 
     # increment by one the value to be sure to keep the current day if the backup_keep <= 0
-    [ ${backup_keep} -le 0 ] && backup_keep=1
+    #[ ${backup_keep} -le 0 ] && backup_keep=1
 
     # reassign the backup_keep variable to this step
     local backup_keep_step="${backup_keep}"
@@ -1208,6 +1212,8 @@ backup_erase() {
 
           # using rm (with some nfs connected server, this can be problematic)
 	  rm -rf "${bck}"
+          # nfs qnap crap!
+          #rm -rf "${bck}" >/dev/null 2>&1 
 
           # using find
           #if [ -d "${bck}" ]
@@ -1601,6 +1607,9 @@ backup_schedule() {
  fi
  if echo "${backup_schedule_planning}" | grep -q -w m
    then local run_monthly="$(echo ${backup_schedule_monthly_cron} | grep -q -w $(date +"%e" | tr -d [:space:]); echo $?)"
+	# find the last day of current month, and if today is the last day, run monthly backup
+	local monthly_lastday=$(date +%d -d "-$(date +%d) days +1 month")
+	[[ $(date +"%e" | tr -d [:space:]) -eq ${monthly_lastday} && ${backup_schedule_monthly_cron} -gt ${monthly_lastday} ]] && local run_monthly=0
    else local run_monthly=1
  fi
  if echo "${backup_schedule_planning}" | grep -q -w y
@@ -1608,10 +1617,6 @@ backup_schedule() {
    else local  run_yearly=1
  fi
 
- # find the last day of current month, and if today is the last day, run monthly backup
- local monthly_lastday=$(date +%d -d "-$(date +%d) days +1 month")
- [[ $(date +"%e" | tr -d [:space:]) -eq ${monthly_lastday} && ${backup_schedule_monthly_cron} -gt ${monthly_lastday} ]] && local run_monthly=0
-
  find_good_rsync_backups() {
   # the readlink check is useful to not include invalid cross device links (hardlinking is not possible across different disks and partitions)
   [[ -e "${backup_destination}/yearly/backup-$system"  && "$(dirname $(readlink -f "${backup_destination}/${type}"))" = "$(dirname $(readlink -f "${backup_destination}/yearly"))" ]]  && backup_method_opts="${backup_method_opts} --link-dest=${backup_destination}/yearly/backup-$system"
@@ -1621,7 +1626,7 @@ backup_schedule() {
  }
 
  # anyway execute the backups only if we can keep more than 0 backups of course :)
- if   [[ ${backup_schedule_yearly_keep} -gt 0 && ${run_yearly}  -eq 0 ]]
+ if   [[ ${backup_schedule_yearly_cron} -gt 0 && ${run_yearly}  -eq 0 ]]
    then 
         local type=yearly
         [ ${method} = "rsync" ] && find_good_rsync_backups
@@ -1629,7 +1634,7 @@ backup_schedule() {
 	backup_keep="${backup_schedule_yearly_keep}"
 	method_type="$(msg yearly)"
 
- elif [[ ${backup_schedule_monthly_keep} -gt 0 && ${run_monthly} -eq 0 ]]
+ elif [[ ${backup_schedule_monthly_cron} -gt 0 && ${run_monthly} -eq 0 ]]
    then 
         local type=monthly
         [ ${method} = "rsync" ] && find_good_rsync_backups
@@ -1637,7 +1642,7 @@ backup_schedule() {
 	backup_keep="${backup_schedule_monthly_keep}"
 	method_type="$(msg monthly)"
 
- elif [[ ${backup_schedule_weekly_keep} -gt 0 && ${run_weekly} -eq 0 ]]
+ elif [[ ${backup_schedule_weekly_cron} -gt 0 && ${run_weekly} -eq 0 ]]
    then 
         local type=weekly
         [ ${method} = "rsync" ] && find_good_rsync_backups
@@ -1645,7 +1650,7 @@ backup_schedule() {
 	backup_keep="${backup_schedule_weekly_keep}"
 	method_type="$(msg weekly)"
 
- elif [[ ${backup_schedule_daily_keep} -gt 0 && ${run_daily} -eq 0 ]]
+ elif [[ ${backup_schedule_daily_cron} -gt 0 && ${run_daily} -eq 0 ]]
    then 
         local type=daily
         [ ${method} = "rsync" ] && find_good_rsync_backups
