@@ -280,7 +280,7 @@ make_calendar_config(){
         # don't count the status of backups in the total page, is not useful
         [ "$2" != "total" ] && status_cnt $1 cnt_all
 
-        for dir in $(find $1/ -maxdepth 1 -type d | sed -e 's/^.\///' | grep -wv ^"." | grep -v "$1"$ | sort -r)
+        for dir in $(find $1/ -maxdepth 1 -type d | sed -e 's/^.\///' | grep -wv ^"." | grep -v "$1"/$ | sort -r)
           do
             local rdir=$(basename ${dir})
             local desc=${rdir}
@@ -633,7 +633,7 @@ make_html_index() {
 
 # rebuild all indexes
 rebuild_indexes() {
-  for year in $(find "${report_html_destination}"/ -maxdepth 1 -type d | sed -e 's/^.\///' | grep -wv ^"." | grep -v "${report_html_destination}"$ | sort -r)
+  for year in $(find "${report_html_destination}"/ -maxdepth 1 -type d | sed -e 's/^.\///' | grep -wv ^"." | grep -v "${report_html_destination}"/$ | sort -r)
    do
     for month in $(find "${year}" -maxdepth 1 -type d | sed -e 's/^.\///' | grep -wv ^"." | grep -v "${year}"$ | sort -r)
      do
